Credit card numbers are used in applications where a user is able to
purchase goods and/or services.

A credit card number is a sensitive
piece of information and should be handled as such. Cyber-criminals
will use various methods to attempt to compromise credit card
information that can then be used for fraudulent purposes.

Through
the use of regular expressions and CC number format validation,
It was possible to discover a credit card number located within the
affected page.